@@ -125,7 +125,7 @@ int FanStatus(void)
 	reg.ebx = HCI_FAN;
 	HciFunction(&reg);
 
-	if (reg.eax!=HCI_SUCCESS)
+	if ((reg.eax & 0xff00)!=HCI_SUCCESS)
 		return -1;
 	else
 		return (int) reg.ecx;
